@@ -114,7 +114,7 @@ string = new (function () {
   this.escapeRegExpChars = (function () {
     var specials = [ '^', '$', '/', '.', '*', '+', '?', '|', '(', ')',
         '[', ']', '{', '}', '\\' ];
-    sRE = new RegExp('(\\' + specials.join('|\\') + ')', 'g');
+    var sRE = new RegExp('(\\' + specials.join('|\\') + ')', 'g');
     return function (string) {
       var str = string || '';
       str = String(str);
@@ -708,26 +708,30 @@ string = new (function () {
         // Use plural version to fix possible mistakes(e,g,. thingie instead of thingy)
       , normalizedName = this.snakeize(inflection.pluralize(name))
       , nameSingular = inflection.singularize(normalizedName)
-      , namePlural = inflection.pluralize(normalizedName);
+      , namePlural = inflection.pluralize(normalizedName)
+      , nameNormal = this.snakeize(name);
 
     return {
       // For filepaths or URLs
       filename: {
+        normal: nameNormal
         // neil_peart
-        singular: nameSingular
+      , singular: nameSingular
         // neil_pearts
       , plural: namePlural
       }
       // Constructor names
     , constructor: {
+        normal: self.camelize(nameNormal, {initialCap: true})
         // NeilPeart
-        singular: self.camelize(nameSingular, {initialCap: true})
+      , singular: self.camelize(nameSingular, {initialCap: true})
         // NeilPearts
       , plural: self.camelize(namePlural, {initialCap: true})
       }
     , property: {
+        normal: self.camelize(nameNormal)
         // neilPeart
-        singular: self.camelize(nameSingular)
+      , singular: self.camelize(nameSingular)
         // neilPearts
       , plural: self.camelize(namePlural)
       }
@@ -784,6 +788,25 @@ string = new (function () {
 
     return uuid.join('');
   };
+  
+  /**
+    @name string#stripTags
+    @public
+    @function
+    @return {String} A String with HTML tags removed.
+    @description Strips HTML tags from a string.
+    @param {String} The string to strip HTML tags from
+    @param {String|Array} A String or Array containing allowed tags. e.g. "<br><p>"
+  */
+  this.stripTags = function(string, allowed) {
+    // taken from http://phpjs.org/functions/strip_tags/
+    var allowed = (((allowed || "") + "").toLowerCase().match(/<[a-z][a-z0-9]*>/g) || []).join(''); // making sure the allowed arg is a string containing only tags in lowercase (<a><b><c>)
+    var tags = /<\/?([a-z][a-z0-9]*)\b[^>]*>/gi,
+    comments = /<!--[\s\S]*?-->/gi;
+    return string.replace(comments, '').replace(tags, function ($0, $1) {
+      return allowed.indexOf('<' + $1.toLowerCase() + '>') > -1 ? $0 : '';
+    });
+  }
 
 })();
 
